@@ -15,8 +15,8 @@ namespace mtpk {
  * @brief Summary data structure responsible for returning results
  */
 typedef struct summary {
-    std::vector<std::vector<float>> mean_stdev;
-    float class_prob;
+    std::vector<std::vector<long double>> mean_stdev;
+    long double class_prob;
 } summary;
 
 /**
@@ -25,19 +25,19 @@ typedef struct summary {
 class BayesClf {
     private:
         std::vector<class_summary> Summary;
-        std::vector<float> unique_label;
+        std::vector<long double> unique_label;
 
     public:
-        void fit(std::vector<std::vector<float>> dataset);
-        int predict(const  std::vector<float>& test_data);
+        void fit(std::vector<std::vector<long double>> dataset);
+        int64_t predict(const std::vector<long double>& test_data);
 };
-summary compute_class_summ(std::vector<std::vector<float>> dataset, 
-                            float class_label);
+summary compute_class_summ(std::vector<std::vector<long double>> dataset, 
+                            long double class_label);
 
-float prob_by_summ(const std::vector<float> &test_data, 
+long double prob_by_summ(const std::vector<long double> &test_data, 
                 const class_summary &summary );
 
-} namespace
+} // namespace
 
 #endif
 
